# Changelog

## [v1.3.1](https://github.com/sci-oer/student-cli/releases/v1.3.1) (2023-09-05)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.3.0...v1.3.1)

**Merged pull requests:**

- chore\(deps\): update actions/checkout action to v4 [\#172](https://github.com/sci-oer/student-cli/pull/172) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency shellingham to v1.5.3 [\#171](https://github.com/sci-oer/student-cli/pull/171) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytest to v7.4.1 [\#170](https://github.com/sci-oer/student-cli/pull/170) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency click to v8.1.7 [\#169](https://github.com/sci-oer/student-cli/pull/169) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update pypa/gh-action-pypi-publish action to v1.8.10 [\#168](https://github.com/sci-oer/student-cli/pull/168) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pyparsing to v3.1.1 [\#167](https://github.com/sci-oer/student-cli/pull/167) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency rich to v13.5.2 [\#166](https://github.com/sci-oer/student-cli/pull/166) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pathspec to v0.11.2 [\#165](https://github.com/sci-oer/student-cli/pull/165) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency wheel to v0.41.2 [\#163](https://github.com/sci-oer/student-cli/pull/163) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency platformdirs to v3.10.0 [\#153](https://github.com/sci-oer/student-cli/pull/153) ([renovate[bot]](https://github.com/apps/renovate))

## [v1.3.0](https://github.com/sci-oer/student-cli/releases/v1.3.0) (2023-07-27)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.2.0...v1.3.0)

**Merged pull requests:**

- chore\(deps\): update dependency pyyaml to v6.0.1 [\#160](https://github.com/sci-oer/student-cli/pull/160) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency click to v8.1.6 [\#159](https://github.com/sci-oer/student-cli/pull/159) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pyparsing to v3.1.0 [\#158](https://github.com/sci-oer/student-cli/pull/158) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytest to v7.4.0 [\#157](https://github.com/sci-oer/student-cli/pull/157) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency rich to v13.4.2 [\#156](https://github.com/sci-oer/student-cli/pull/156) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency typing\_extensions to v4.7.1 [\#155](https://github.com/sci-oer/student-cli/pull/155) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency setuptools to v67.8.0 [\#154](https://github.com/sci-oer/student-cli/pull/154) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency docker to v6.1.3 [\#151](https://github.com/sci-oer/student-cli/pull/151) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update pypa/gh-action-pypi-publish action to v1.8.8 [\#150](https://github.com/sci-oer/student-cli/pull/150) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency typer to v0.9.0 [\#149](https://github.com/sci-oer/student-cli/pull/149) ([renovate[bot]](https://github.com/apps/renovate))

## [v1.2.0](https://github.com/sci-oer/student-cli/releases/v1.2.0) (2023-04-30)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.1.0...v1.2.0)

**Implemented enhancements:**

- feat: add readline so prompts can be edited [\#148](https://github.com/sci-oer/student-cli/pull/148) ([MarshallAsch](https://github.com/MarshallAsch))

**Merged pull requests:**

- chore!: turn off windows ci piplines that keep failing [\#147](https://github.com/sci-oer/student-cli/pull/147) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: update release notes template [\#146](https://github.com/sci-oer/student-cli/pull/146) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: auto tag renovate prs as dependancy updates [\#145](https://github.com/sci-oer/student-cli/pull/145) ([MarshallAsch](https://github.com/MarshallAsch))
- chore\(deps\): update dependency attrs to v23 [\#144](https://github.com/sci-oer/student-cli/pull/144) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency packaging to v23.1 [\#143](https://github.com/sci-oer/student-cli/pull/143) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency black to v23.3.0 [\#142](https://github.com/sci-oer/student-cli/pull/142) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pathspec to v0.11.1 [\#141](https://github.com/sci-oer/student-cli/pull/141) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency wheel to v0.40.0 [\#140](https://github.com/sci-oer/student-cli/pull/140) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update pypa/gh-action-pypi-publish action to v1.8.5 [\#139](https://github.com/sci-oer/student-cli/pull/139) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency setuptools to v67.7.2 [\#138](https://github.com/sci-oer/student-cli/pull/138) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency rich to v13.3.5 [\#137](https://github.com/sci-oer/student-cli/pull/137) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency platformdirs to v3.5.0 [\#136](https://github.com/sci-oer/student-cli/pull/136) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytest to v7.3.1 [\#135](https://github.com/sci-oer/student-cli/pull/135) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytype to v2023.4.27 [\#134](https://github.com/sci-oer/student-cli/pull/134) ([renovate[bot]](https://github.com/apps/renovate))

## [v1.1.0](https://github.com/sci-oer/student-cli/releases/v1.1.0) (2023-02-25)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.0.2...v1.1.0)

**Implemented enhancements:**

- wiki and jupyter have a startup permissions issue [\#46](https://github.com/sci-oer/student-cli/issues/46)
- short help should include the basic command options [\#35](https://github.com/sci-oer/student-cli/issues/35)
- chore: cleanup documentation and default example resource image' [\#125](https://github.com/sci-oer/student-cli/pull/125) ([MarshallAsch](https://github.com/MarshallAsch))

**Merged pull requests:**

- chore\(deps\): update dependency setuptools to v67 [\#133](https://github.com/sci-oer/student-cli/pull/133) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency rich to v13 [\#132](https://github.com/sci-oer/student-cli/pull/132) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytype to v2023 [\#131](https://github.com/sci-oer/student-cli/pull/131) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency platformdirs to v3 [\#130](https://github.com/sci-oer/student-cli/pull/130) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency packaging to v23 [\#129](https://github.com/sci-oer/student-cli/pull/129) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency mypy-extensions to v1 [\#128](https://github.com/sci-oer/student-cli/pull/128) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency iniconfig to v2 [\#127](https://github.com/sci-oer/student-cli/pull/127) ([renovate[bot]](https://github.com/apps/renovate))
- fix: remove deprecated set-output command in workflow [\#126](https://github.com/sci-oer/student-cli/pull/126) ([MarshallAsch](https://github.com/MarshallAsch))
- chore\(deps\): update dependency black to v23 [\#124](https://github.com/sci-oer/student-cli/pull/124) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update pypa/gh-action-pypi-publish action to v1.6.4 [\#123](https://github.com/sci-oer/student-cli/pull/123) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency setuptools to v65.7.0 [\#122](https://github.com/sci-oer/student-cli/pull/122) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pathspec to v0.11.0 [\#121](https://github.com/sci-oer/student-cli/pull/121) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency attrs to v22.2.0 [\#120](https://github.com/sci-oer/student-cli/pull/120) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency shellingham to v1.5.1 [\#119](https://github.com/sci-oer/student-cli/pull/119) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency mypy-extensions to v0.4.4 [\#118](https://github.com/sci-oer/student-cli/pull/118) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency wheel to v0.38.1 \[security\] [\#117](https://github.com/sci-oer/student-cli/pull/117) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency setuptools to v65.5.1 \[security\] [\#116](https://github.com/sci-oer/student-cli/pull/116) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency platformdirs to v2.6.2 [\#112](https://github.com/sci-oer/student-cli/pull/112) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency typer to v0.7.0 [\#111](https://github.com/sci-oer/student-cli/pull/111) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency wheel to v0.38.4 [\#110](https://github.com/sci-oer/student-cli/pull/110) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency docker to v6.0.1 [\#109](https://github.com/sci-oer/student-cli/pull/109) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytest to v7.2.1 [\#108](https://github.com/sci-oer/student-cli/pull/108) ([renovate[bot]](https://github.com/apps/renovate))
- fix: cleanup copy paste errors from work author email and keywords [\#107](https://github.com/sci-oer/student-cli/pull/107) ([MarshallAsch](https://github.com/MarshallAsch))
- chore\(deps\): update dependency typing\_extensions to v4.5.0 [\#106](https://github.com/sci-oer/student-cli/pull/106) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency black to v22.12.0 [\#105](https://github.com/sci-oer/student-cli/pull/105) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency rich to v12.6.0 [\#104](https://github.com/sci-oer/student-cli/pull/104) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency setuptools to v65.6.3 [\#103](https://github.com/sci-oer/student-cli/pull/103) ([renovate[bot]](https://github.com/apps/renovate))
- chore\(deps\): update dependency pytype to v2022.12.15 [\#94](https://github.com/sci-oer/student-cli/pull/94) ([renovate[bot]](https://github.com/apps/renovate))

## [v1.0.2](https://github.com/sci-oer/student-cli/releases/v1.0.2) (2022-09-16)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.0.1...v1.0.2)

**Implemented enhancements:**

- config file location in status output [\#98](https://github.com/sci-oer/student-cli/issues/98)

**Fixed bugs:**

- add more details to the unknown error message [\#97](https://github.com/sci-oer/student-cli/issues/97)
- info log not printing contents of the config file [\#95](https://github.com/sci-oer/student-cli/issues/95)

**Merged pull requests:**

- fix: add the config file path to the status output [\#102](https://github.com/sci-oer/student-cli/pull/102) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: add the explination to the error message for the unknown docker errors [\#101](https://github.com/sci-oer/student-cli/pull/101) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: now log the content of the course config block to the info log [\#100](https://github.com/sci-oer/student-cli/pull/100) ([MarshallAsch](https://github.com/MarshallAsch))

## [v1.0.1](https://github.com/sci-oer/student-cli/releases/v1.0.1) (2022-09-08)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v1.0.0...v1.0.1)

**Merged pull requests:**

- fix: update license string [\#93](https://github.com/sci-oer/student-cli/pull/93) ([MarshallAsch](https://github.com/MarshallAsch))

## [v1.0.0](https://github.com/sci-oer/student-cli/releases/v1.0.0) (2022-09-08)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.6.2...v1.0.0)

**Merged pull requests:**

- chore: bump pypi classifier to stable [\#92](https://github.com/sci-oer/student-cli/pull/92) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: replace container.run\_exec with a docker exec system call [\#91](https://github.com/sci-oer/student-cli/pull/91) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: improve log message and general messages [\#90](https://github.com/sci-oer/student-cli/pull/90) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: handle name in use, image not found, and unkown docker api erros on start [\#89](https://github.com/sci-oer/student-cli/pull/89) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: add multiple log level options [\#88](https://github.com/sci-oer/student-cli/pull/88) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: load bash profile when starting shell in container [\#87](https://github.com/sci-oer/student-cli/pull/87) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: change build tooling to pyproject and switch versioning tool [\#86](https://github.com/sci-oer/student-cli/pull/86) ([MarshallAsch](https://github.com/MarshallAsch))
- Update dependency pathspec to v0.10.1 [\#84](https://github.com/sci-oer/student-cli/pull/84) ([renovate[bot]](https://github.com/apps/renovate))

## [v0.6.2](https://github.com/sci-oer/student-cli/releases/v0.6.2) (2022-09-05)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.6.1...v0.6.2)

**Fixed bugs:**

- fix: use platform agnostic HOME path expansion in thestatus volume [\#85](https://github.com/sci-oer/student-cli/pull/85) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.6.1](https://github.com/sci-oer/student-cli/releases/v0.6.1) (2022-09-02)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.6.0...v0.6.1)

**Merged pull requests:**

- Update dependency pytest to v7.1.3 [\#83](https://github.com/sci-oer/student-cli/pull/83) ([renovate[bot]](https://github.com/apps/renovate))
- fix: only open the container ports to localhost unless the public config option is set [\#82](https://github.com/sci-oer/student-cli/pull/82) ([MarshallAsch](https://github.com/MarshallAsch))
- Update dependency black to v22.8.0 [\#81](https://github.com/sci-oer/student-cli/pull/81) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency pathspec to v0.10.0 [\#78](https://github.com/sci-oer/student-cli/pull/78) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency pytype to v2022.8.30 [\#77](https://github.com/sci-oer/student-cli/pull/77) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency colorlog to v6.7.0 [\#74](https://github.com/sci-oer/student-cli/pull/74) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency setuptools to v65 [\#64](https://github.com/sci-oer/student-cli/pull/64) ([renovate[bot]](https://github.com/apps/renovate))

## [v0.6.0](https://github.com/sci-oer/student-cli/releases/v0.6.0) (2022-08-31)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.5.1...v0.6.0)

**Merged pull requests:**

- fix: fix home path env var expansion on windows [\#80](https://github.com/sci-oer/student-cli/pull/80) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: delete old image version after a new version is pulled [\#79](https://github.com/sci-oer/student-cli/pull/79) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.5.1](https://github.com/sci-oer/student-cli/releases/v0.5.1) (2022-08-30)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.5.0...v0.5.1)

**Implemented enhancements:**

- no pull as the default behaviour if there is a matching image [\#68](https://github.com/sci-oer/student-cli/issues/68)
- did not print the MOD when starting a shell [\#48](https://github.com/sci-oer/student-cli/issues/48)
- feat!: added auto fetch as a configuration option that can be overwridden at start time [\#75](https://github.com/sci-oer/student-cli/pull/75) ([MarshallAsch](https://github.com/MarshallAsch))

**Fixed bugs:**

- fix: did not print the MOTD when starting a shell in the container [\#76](https://github.com/sci-oer/student-cli/pull/76) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.5.0](https://github.com/sci-oer/student-cli/releases/v0.5.0) (2022-08-29)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.4.1...v0.5.0)

**Implemented enhancements:**

- message after scioer start [\#69](https://github.com/sci-oer/student-cli/issues/69)
- Add support for keeping track of runtime information [\#5](https://github.com/sci-oer/student-cli/issues/5)
- Load options by default from a config file [\#4](https://github.com/sci-oer/student-cli/issues/4)
- feat: print some help information when the course resource is started [\#73](https://github.com/sci-oer/student-cli/pull/73) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: add basic course status command [\#72](https://github.com/sci-oer/student-cli/pull/72) ([MarshallAsch](https://github.com/MarshallAsch))

**Fixed bugs:**

- fix: Create intermediate config file directories [\#71](https://github.com/sci-oer/student-cli/pull/71) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.4.1](https://github.com/sci-oer/student-cli/releases/v0.4.1) (2022-08-26)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.4.0...v0.4.1)

**Merged pull requests:**

- fix: corrected pytype issues [\#65](https://github.com/sci-oer/student-cli/pull/65) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.4.0](https://github.com/sci-oer/student-cli/releases/v0.4.0) (2022-08-23)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.3.0...v0.4.0)

**Merged pull requests:**

- chore: update dependancy files, added shellingham and rich for pretty printing [\#62](https://github.com/sci-oer/student-cli/pull/62) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: update the help messages [\#61](https://github.com/sci-oer/student-cli/pull/61) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: removed extra / in the ports regex [\#60](https://github.com/sci-oer/student-cli/pull/60) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: remove setting the uid and guid of the user that the container runs as [\#59](https://github.com/sci-oer/student-cli/pull/59) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.3.0](https://github.com/sci-oer/student-cli/releases/v0.3.0) (2022-08-19)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.2.0...v0.3.0)

**Implemented enhancements:**

- check that start will reuse a container if it already exists [\#47](https://github.com/sci-oer/student-cli/issues/47)
- set the host name of the docker container when it starts so the container  [\#44](https://github.com/sci-oer/student-cli/issues/44)
- if no course name is specified and there is only a single course in the config file use that one [\#43](https://github.com/sci-oer/student-cli/issues/43)
- for the config command use the ~/.scioer.yaml by default [\#41](https://github.com/sci-oer/student-cli/issues/41)
- should not need to specify the config file it should load the default [\#39](https://github.com/sci-oer/student-cli/issues/39)
- single custom port should forward the same port [\#38](https://github.com/sci-oer/student-cli/issues/38)
- Change default storage path to home [\#37](https://github.com/sci-oer/student-cli/issues/37)
- Implement basic start command [\#9](https://github.com/sci-oer/student-cli/issues/9)
- feat: ask they user if they want the default ports instead of asking about each port [\#58](https://github.com/sci-oer/student-cli/pull/58) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: use desktop as storage path instead of ~/.local [\#57](https://github.com/sci-oer/student-cli/pull/57) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: set hostname in the container [\#56](https://github.com/sci-oer/student-cli/pull/56) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: missed default course name in the start command [\#55](https://github.com/sci-oer/student-cli/pull/55) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: default to the one course if there is only one configured course [\#53](https://github.com/sci-oer/student-cli/pull/53) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: if the course container already exists do not recreate it [\#52](https://github.com/sci-oer/student-cli/pull/52) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: no longer print that the port mapping is wrong when none is given [\#50](https://github.com/sci-oer/student-cli/pull/50) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: automaticly load the default config file [\#49](https://github.com/sci-oer/student-cli/pull/49) ([MarshallAsch](https://github.com/MarshallAsch))

**Fixed bugs:**

- no port in the config should not print an error [\#42](https://github.com/sci-oer/student-cli/issues/42)
- make sure path gets expanded for config file [\#36](https://github.com/sci-oer/student-cli/issues/36)
- fix: expand the paths that are passed in for the data dir and config file [\#54](https://github.com/sci-oer/student-cli/pull/54) ([MarshallAsch](https://github.com/MarshallAsch))

**Merged pull requests:**

- feat: when a single port is specified then use that value for the host and the container port number [\#51](https://github.com/sci-oer/student-cli/pull/51) ([MarshallAsch](https://github.com/MarshallAsch))

## [v0.2.0](https://github.com/sci-oer/student-cli/releases/v0.2.0) (2022-08-11)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.1.0...v0.2.0)

**Implemented enhancements:**

- Add the ports specifications to the config file [\#31](https://github.com/sci-oer/student-cli/issues/31)
- flip no pull option [\#10](https://github.com/sci-oer/student-cli/issues/10)
- Check that docker is installed and running [\#6](https://github.com/sci-oer/student-cli/issues/6)
- feat: add port mapping to the config file and pass the ports numbers into the container [\#33](https://github.com/sci-oer/student-cli/pull/33) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: check that docker is running before starting [\#28](https://github.com/sci-oer/student-cli/pull/28) ([MarshallAsch](https://github.com/MarshallAsch))
- feat!: Make config file flag consistent [\#27](https://github.com/sci-oer/student-cli/pull/27) ([MarshallAsch](https://github.com/MarshallAsch))
- chore!: flip the default value for the pull option [\#24](https://github.com/sci-oer/student-cli/pull/24) ([MarshallAsch](https://github.com/MarshallAsch))

**Fixed bugs:**

- Rename pip package to  for publication [\#29](https://github.com/sci-oer/student-cli/issues/29)

**Closed issues:**

- remove test commands [\#30](https://github.com/sci-oer/student-cli/issues/30)

**Merged pull requests:**

- chore!: remove test command: [\#32](https://github.com/sci-oer/student-cli/pull/32) ([MarshallAsch](https://github.com/MarshallAsch))
- chore: Update dependency attrs to v22 [\#26](https://github.com/sci-oer/student-cli/pull/26) ([renovate[bot]](https://github.com/apps/renovate))
- Update actions/setup-python action to v4 [\#25](https://github.com/sci-oer/student-cli/pull/25) ([renovate[bot]](https://github.com/apps/renovate))
- Update actions/checkout action to v3 [\#23](https://github.com/sci-oer/student-cli/pull/23) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency typing\_extensions to v4.3.0 [\#22](https://github.com/sci-oer/student-cli/pull/22) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency typer to v0.6.1 [\#21](https://github.com/sci-oer/student-cli/pull/21) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency black to v22.6.0 [\#20](https://github.com/sci-oer/student-cli/pull/20) ([renovate[bot]](https://github.com/apps/renovate))

## [v0.1.0](https://github.com/sci-oer/student-cli/releases/v0.1.0) (2022-08-01)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.0.1...v0.1.0)

**Implemented enhancements:**

- Release to PyPi [\#1](https://github.com/sci-oer/student-cli/issues/1)

**Merged pull requests:**

- Update dependency pytest to v7.1.2 [\#19](https://github.com/sci-oer/student-cli/pull/19) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency pyparsing to v3.0.9 [\#18](https://github.com/sci-oer/student-cli/pull/18) ([renovate[bot]](https://github.com/apps/renovate))
- fix: missing dependancies in the test pipeline [\#17](https://github.com/sci-oer/student-cli/pull/17) ([MarshallAsch](https://github.com/MarshallAsch))
- Update dependency platformdirs to v2.5.2 [\#15](https://github.com/sci-oer/student-cli/pull/15) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency click to v8.1.3 [\#14](https://github.com/sci-oer/student-cli/pull/14) ([renovate[bot]](https://github.com/apps/renovate))
- feat: add pipline to automaticly create and release a new version [\#13](https://github.com/sci-oer/student-cli/pull/13) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: add inital manifest file to prevent too many files from being included [\#12](https://github.com/sci-oer/student-cli/pull/12) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: remove incorrectly commited application config file [\#11](https://github.com/sci-oer/student-cli/pull/11) ([MarshallAsch](https://github.com/MarshallAsch))
- Configure Renovate [\#7](https://github.com/sci-oer/student-cli/pull/7) ([renovate[bot]](https://github.com/apps/renovate))

## [v0.0.1](https://github.com/sci-oer/student-cli/releases/v0.0.1) (2022-04-04)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/d0de775a4608f1aeecebf963071d5bbbb77b3c3f...v0.0.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
